@@ -41,7 +41,7 @@ int main(int argc,char **argv)
     set_application("arequipad");
     set_verbosity(NULL,DIAG_INFO);
     background = 0;
-    while ((c = getopt(argc,argv,"bdn")) != EOF)
+    while ((c = getopt(argc,argv,"bdl:n")) != EOF)
 	switch (c) {
 	    case 'b':
 		background = 1;
