@@ -417,7 +417,7 @@ void send_packet(int fd,void *data,int length)
 }
 
 
-int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask)
+int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask,int *mtu)
 {
     struct ifreq req;
     unsigned char *p1,*p2;
@@ -434,10 +434,15 @@ int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask)
     }
     *netmask = ((struct sockaddr_in *) &req.ifr_ifru.ifru_netmask)->
       sin_addr.s_addr;
+    if (ioctl(inet,SIOCGIFMTU,&req) < 0) {
+	diag(COMPONENT,DIAG_ERROR,"ioctl SIOCGIFMTU: %s",strerror(errno));
+	return -1;
+    }
+    *mtu = req.ifr_ifru.ifru_mtu;
     p1 = (unsigned char *) ip;
     p2 = (unsigned char *) netmask;
-    diag(COMPONENT,DIAG_DEBUG,"ip %d.%d.%d.%d mask %d.%d.%d.%d",
-      p1[0],p1[1],p1[2],p1[3],p2[0],p2[1],p2[2],p2[3]);
+    diag(COMPONENT,DIAG_DEBUG,"ip %d.%d.%d.%d mask %d.%d.%d.%d mtu %d",
+      p1[0],p1[1],p1[2],p1[3],p2[0],p2[1],p2[2],p2[3],*mtu);
     return 0;
 }
 
