@@ -113,16 +113,17 @@ static void dump_entries(ENTRY *list)
       "netmask","NULL","ARPSRV" }; /* lower case flags are not used by ATMARP */
     ENTRY *entry;
     VCC *vcc;
-    char buffer[MAX_ATM_ADDR_LEN+1];
+    char addr_buf[MAX_ATM_ADDR_LEN+1];
+    char qos_buf[MAX_ATM_QOS_LEN+1];
     char tmp[100]; /* large enough for all flags */
     unsigned char *ipp;
     int i;
 
     for (entry = list; entry ; entry = entry->next) {
-	if (!entry->addr) strcpy(buffer,"<none>");
-	else if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,
+	if (!entry->addr) strcpy(addr_buf,"<none>");
+	else if (atm2text(addr_buf,MAX_ATM_ADDR_LEN+1,
 	      (struct sockaddr *) entry->addr,pretty) < 0)
-		strcpy(buffer,"<error>");
+		strcpy(addr_buf,"<error>");
 	ipp = (unsigned char *) &entry->ip;
 	*tmp = 0;
 	for (i = 0; i < 8; i++)
@@ -131,8 +132,13 @@ static void dump_entries(ENTRY *list)
 		strcat(tmp,flag_name[i]);
 	    }
 	output("IP %d.%d.%d.%d, state %s, addr %s, flags 0x%x<%s>",ipp[0],
-	  ipp[1],ipp[2],ipp[3],entry_state_name[entry->state],buffer,
+	  ipp[1],ipp[2],ipp[3],entry_state_name[entry->state],addr_buf,
 	  entry->flags,tmp);
+	if (entry->itf && !qos_equal(&entry->itf->qos,&entry->qos)) {
+	    if (qos2text(qos_buf,sizeof(qos_buf),&entry->qos,0) < 0)
+		strcpy(qos_buf,"<error>");
+		output("  QOS: %s",qos_buf);
+	}
 	for (vcc = entry->vccs; vcc; vcc = vcc->next) dump_vcc(vcc);
     }
 }
@@ -141,10 +147,13 @@ static void dump_entries(ENTRY *list)
 static void dump_itf(ITF *itf)
 {
     unsigned char *ipp;
+    char buf[MAX_ATM_QOS_LEN+1];
 
+    if (qos2text(buf,sizeof(buf),&itf->qos,0) < 0) strcpy(buf,"<error>");
     ipp = (unsigned char *) &itf->local_ip;
     output("----- Itf %d (%d.%d.%d.%d) -----",itf->number,ipp[0],ipp[1],
       ipp[2],ipp[3]);
+    output("Default QOS: %s",buf);
     dump_entries(itf->table);
 }
 
