@@ -56,10 +56,11 @@ static void usage(const char *name)
 {
     fprintf(stderr,"usage: %s -a\n",name);
     fprintf(stderr,"%6s %s -c [[atm]N]\n","",name);
-    fprintf(stderr,"%6s %s -s ip_addr [itf.]vpi.vci [pcr value] [temp] [pub]"
-      " [null]\n","",name);
-    fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [temp] [pub] "
-      "[arpsrv]\n","",name);
+    fprintf(stderr,"%6s %s -q ip_addr qos_spec\n","",name);
+    fprintf(stderr,"%6s %s -s ip_addr [itf.]vpi.vci [pcr value] [qos spec] "
+      "[temp] [pub] [null]\n","",name);
+    fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [qos spec] [temp] "
+      "[pub] [arpsrv]\n","",name);
     fprintf(stderr,"%6s %s -d ip_addr [arpsrv]\n","",name);
     exit(1);
 }
@@ -70,10 +71,12 @@ int main(int argc,char **argv)
     struct hostent *hostent;
     struct atmarpreq req;
     int c,op,s,i,req_num,num;
+    const char *qos;
     char *here,*end;
 
     op = 0;
-    while ((c = getopt(argc,argv,"acds")) != EOF)
+    qos = NULL;
+    while ((c = getopt(argc,argv,"acdqs")) != EOF)
 	switch (c) {
 	    case 'a':
 		if (argc != optind) usage(argv[0]);
@@ -82,6 +85,11 @@ int main(int argc,char **argv)
 		if (op) usage(argv[0]);
 		op = SIOCMKCLIP;
 		break;
+	    case 'q':
+		if (op) usage(argv[0]);
+		op = SIOCSARP;
+		qos = ""; /* non-NULL */
+		break;
 	    case 's':
 		if (op) usage(argv[0]);
 		op = SIOCSARP;
@@ -118,6 +126,7 @@ int main(int argc,char **argv)
 	    return 0;
 	case SIOCSARP:
 	    if (argc < optind+2) usage(argv[0]);
+	    if (qos && argc > optind+2) usage(argv[0]);
 	    break;
 	case SIOCDARP:
 	    if (argc < optind+1) usage(argv[0]);
@@ -146,24 +155,30 @@ int main(int argc,char **argv)
 	  hostent->h_length);
     }
     req.arp_flags = ATF_PERM;
-    if (op == SIOCSARP) {
+    if (op == SIOCSARP && qos) {
+	req.arp_flags |= ATF_DEFQOS;
+	if (text2qos(argv[optind+1],&req.arp_qos,0)) usage(argv[0]);
+    }
+    if (op == SIOCSARP && !qos) {
 	memset(&req.arp_qos,0,sizeof(req.arp_qos));
-	req.arp_qos.txtp.traffic_class = ATM_UBR;
 	for (i = optind+2; i < argc; i++)
-		if (!strcmp(argv[i],"temp")) req.arp_flags &= ~ATF_PERM;
-		else if (!strcmp(argv[i],"pub")) req.arp_flags |= ATF_PUBL;
-		else if (!strcmp(argv[i],"null")) req.arp_flags |= ATF_NULL;
-		else if (!strcmp(argv[i],"arpsrv")) req.arp_flags |= ATF_ARPSRV;
-		else if (!strcmp(argv[i],"pcr")) {
-			if (++i >= argc) usage(argv[0]);
-			req.arp_qos.txtp.max_pcr = strtol(argv[i],&end,0);
-			if (*end) usage(argv[0]);
-		    }
-		else usage(argv[0]);
-#if 0 /* atmarpd now sets max_sdu if 0 */
-	req.arp_qos.txtp.max_sdu = RFC1483LLC_LEN+RFC1626_MTU;
-#endif
-	req.arp_qos.rxtp = req.arp_qos.txtp;
+	    if (!strcmp(argv[i],"temp")) req.arp_flags &= ~ATF_PERM;
+	    else if (!strcmp(argv[i],"pub")) req.arp_flags |= ATF_PUBL;
+	    else if (!strcmp(argv[i],"null")) req.arp_flags |= ATF_NULL;
+	    else if (!strcmp(argv[i],"arpsrv")) req.arp_flags |= ATF_ARPSRV;
+	    else if (!strcmp(argv[i],"qos")) {
+		    if (++i >= argc) usage(argv[0]);
+		    if (text2qos(argv[i],&req.arp_qos,0)) usage(argv[0]);
+		}
+	    else if (!strcmp(argv[i],"pcr")) {
+		    if (++i >= argc) usage(argv[0]);
+		    req.arp_qos.txtp.traffic_class =
+		      req.arp_qos.rxtp.traffic_class = ATM_CBR;
+		    req.arp_qos.txtp.max_pcr = req.arp_qos.rxtp.max_pcr =
+		      strtol(argv[i],&end,0);
+		    if (*end) usage(argv[0]);
+		}
+	    else usage(argv[0]);
 	if (text2atm(argv[optind+1],(struct sockaddr *) &req.arp_ha,
 	  sizeof(req.arp_ha),T2A_NAME) < 0) {
 	    fprintf(stderr,"%s: invalid ATM address\n",argv[optind+1]);
