@@ -11,10 +11,10 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include <linux/atm.h>
-#include <linux/atmsap.h>
 #include <assert.h>
 
 /* Local includes */
+#include "atmsap.h"
 #include "atm_lecs.h"
 
 /* Data */
