@@ -47,6 +47,7 @@
 
 #include <linux/atm.h>
 #include <linux/atmdev.h>
+#include <atm.h>
 
 /* Digital includes */
 #include "codes.h"
@@ -114,7 +115,6 @@ typedef struct _Sap_client_t_ {
   SAP_RCV_CALLBACK rcv_callback;
   SAP_VC_NOTIFY_CALLBACK vc_notify_callback;
   SAP_CONNECT_CALLBACK svc_connect_callback;
-  SAP_LINK_STATUS_CALLBACK link_status_callback;
   SAP_XMT_DONE_CALLBACK xmt_done_callback;
   char *p_sap_text;
   unsigned long xmt_packet_count;
@@ -140,7 +140,6 @@ cm_sap_register(HANDLE sap_context,
 		SAP_RCV_CALLBACK rcv_callback, 
 		SAP_VC_NOTIFY_CALLBACK vc_notify_callback,
 		SAP_CONNECT_CALLBACK svc_connect_callback,
-		SAP_LINK_STATUS_CALLBACK link_status_callback,
 		SAP_XMT_DONE_CALLBACK xmt_done_callback,
 		int itf_num,
 		const char *p_sap_text, HANDLE *p_sap_handle)
@@ -158,7 +157,6 @@ cm_sap_register(HANDLE sap_context,
   client->rcv_callback = rcv_callback;
   client->vc_notify_callback = vc_notify_callback;
   client->svc_connect_callback = svc_connect_callback;
-  client->link_status_callback = link_status_callback;
   client->xmt_done_callback = xmt_done_callback;
 
   /* Allocate space etc for text string */
@@ -875,7 +873,7 @@ conn_check_incoming(fd_set *fds)
 
 int
 conn_create_listensocket(HANDLE sap_handle, HANDLE conn_context,
-			 unsigned short blli_codepoint, int max_cell_rate,
+			 unsigned short blli_codepoint, const char *qos_spec,
 			 HANDLE *p_conn_handle)
 {
   int fd, ret, len;
@@ -895,8 +893,6 @@ conn_create_listensocket(HANDLE sap_handle, HANDLE conn_context,
 
   conn_info->conqos.txtp.traffic_class = ATM_UBR;
   conn_info->conqos.rxtp.traffic_class = ATM_UBR;
-  conn_info->conqos.txtp.max_pcr = max_cell_rate;  
-  conn_info->conqos.rxtp.max_pcr = max_cell_rate;
 
   switch (blli_codepoint) {
   case BLLI_CONTROL:
@@ -914,6 +910,10 @@ conn_create_listensocket(HANDLE sap_handle, HANDLE conn_context,
     EVENT(EM_ASSERT,("Unknown BLLI codepoint:%x\n",blli_codepoint));
   }
 
+  if (qos_spec)
+    if (text2qos(qos_spec,&conn_info->conqos,T2Q_DEFAULTS) < 0)
+      EVENT(EM_ASSERT,("text2qos failed in conn_create_listensocket\n"));
+
   /* Set traffic parameters */
   if (setsockopt(fd,SOL_ATM,SO_ATMQOS, &(conn_info->conqos), 
 		 sizeof(conn_info->conqos)) < 0) {
