@@ -8,7 +8,9 @@
 #include <sys/ioctl.h>
 #include <linux/arequipa.h>
 #include <linux/atm.h>
+#include <linux/atmclip.h>
 
+#include "atmsap.h"
 #include "arequipa.h"
 
 
@@ -16,11 +18,15 @@ int arequipa_preset(int sd,const struct sockaddr_atmsvc *addr,
   const struct atm_qos *qos)
 {
     struct sockaddr_atmsvc a;
+    struct atm_qos q;
     struct atm_blli blli;
     int s;
 
     if ((s = socket(addr->sas_family,SOCK_DGRAM,ATM_AAL5)) < 0) return -1;
-    if (setsockopt(s,SOL_ATM,SO_ATMQOS,qos,sizeof(struct atm_qos)) < 0) {
+    q = *qos;
+    if (!q.txtp.max_sdu) q.txtp.max_sdu = RFC1626_MTU+RFC1483LLC_LEN;
+    if (!q.rxtp.max_sdu) q.rxtp.max_sdu = RFC1626_MTU+RFC1483LLC_LEN;
+    if (setsockopt(s,SOL_ATM,SO_ATMQOS,&q,sizeof(q)) < 0) {
 	(void) close(s);
 	return -1;
     }
