@@ -25,6 +25,8 @@ typedef struct _name_list {
 typedef struct {
     /* --- the following fields are initialized by the parser */
     VALUE_TYPE type;
+    const char *recovery; /* only valid if vt_length; NULL if not used */
+    const char *abort_id; /* non-NULL to request application-specific error */
     const char *id; /* for value-only and for default tag */
     struct _field *block; /* length */
     struct _tag *tags; /* case or multi */
@@ -69,6 +71,7 @@ typedef struct _tag {
     VALUE_LIST *more; /* only for named selectors */
     const char *value;
     FIELD *block;
+    const char *abort_id; /* non-NULL to request application-specific error */
     struct _tag *next;
     int deflt;
     /* --- the following fields are initialized in the first phase */
