@@ -707,7 +707,7 @@ static void set_data_transfer_timers(SSCOP_DSC *dsc) /* 20.51 */
 
 static void initialize_vr_mr(SSCOP_DSC *dsc)
 {
-    dsc->vr_mr = MOD24(dsc->vr_h+SSCOP_CF_MR);
+    dsc->vr_mr = SSCOP_CF_MR; /* was MOD24(dsc->vr_h+SSCOP_CF_MR); */
 }
 
 
@@ -868,7 +868,7 @@ static void try_to_send(SSCOP_DSC *dsc)
 	    emit_pdu(dsc,buf);
 	    buf2->extra = dsc->vt_ps;
 #ifdef POLL_AFTER_RETRANSMISSION
-	    if (!queue_peek(dsc->rt_q))
+	    if (queue_peek(dsc->rt_q))
 		/* fall through to goto */
 #endif
 	    goto B; /* sigh ... */
@@ -1293,7 +1293,7 @@ static int handle_sscop_pdu(SSCOP_DSC *dsc,void *msg,int size)
 		    bad_pdu(dsc,type);
 		    next_state(dsc,sscop_idle);
 		    if (dsc->ops->rel_ind)
-			dsc->ops->rel_ind(dsc->user,NULL,0,1);
+			dsc->ops->rel_ind(dsc->user,NULL,0,0);
 		    return 0;
 		case SSCOP_SD:
 		case SSCOP_USTAT:
