@@ -33,7 +33,7 @@ const char *qs_name[] = {
 	"REL_IND" };
 
 const char *as_name[] = { "<invalid>","as_bind","as_connect","as_accept",
-  "as_listen","as_okay","as_error","as_indicate","as_close" };
+  "as_reject","as_listen","as_okay","as_error","as_indicate","as_close" };
 
 const Q2931_STATE state_map[] = { /* formatting aligned with STATE */
 	qs_null,	qs_null,	qs_null,	qs_call_init,
