@@ -11,11 +11,11 @@
 #include <sys/time.h>
 
 #include <linux/atm.h>
-#include <linux/atmsap.h>
 #include <linux/atmsvc.h>
 
 #include "atm.h"
 #include "atmd.h"
+#include "atmsap.h"
 #include "trace.h"
 
 
@@ -188,7 +188,7 @@ static void print_kernel(void *msg,int size)
       sizeof(*bhli) ? bhli[m->svc.sas_addr.bhli.hl_type] : "???");
     if (m->svc.sas_addr.bhli.hl_type == ATM_HL_USER ||
       m->svc.sas_addr.bhli.hl_type == ATM_HL_ISO)
-	for (i = 0; i < m->svc.sas_addr.bhli.hl_type; i++)
+	for (i = 0; i < m->svc.sas_addr.bhli.hl_length; i++)
 	    append(" %02x",m->svc.sas_addr.bhli.hl_info[i]);
     append("\n");
     for (i = 0; i <= (size-(int) sizeof(struct atmsvc_msg))/
